#[repr(C)]pub struct DownsamplingConstants {
pub mips: u32,
pub inverse_input_size: Vec2,
pub _padding: u32,
}Expand description
Constants for the single-pass downsampling shader generated on the CPU and read on the GPU.
These constants are stored within a uniform buffer. There’s one such uniform buffer per image.
Fields
mips: u32The number of mip levels that this image possesses.
inverse_input_size: Vec2The reciprocal of the size of the first mipmap level for this texture.
_padding: u32Padding.