MipGenerationPhaseId

Struct MipGenerationPhaseId 

pub struct MipGenerationPhaseId(pub u32);
Identifies a phase during which mipmaps will be generated for an image.

Sometimes, mipmaps must be generated at a specific time during the rendering process. This typically occurs when a camera renders to the image and then the image is sampled later in the frame as a second camera renders the scene. In this case, the mipmaps must be generated after the first camera renders to the image rendered to but before the second camera’s rendering samples the image. To express these kinds of dependencies, you group images into phases and schedule systems that call generate_mips_for_phase targeting each phase at the appropriate time.

Each phase has an ID, which is an arbitrary 32-bit integer. You may specify any value you wish as a phase ID, so long as the system that calls generate_mips_for_phase uses the same ID.

Tuple Fields

0: u32